using System;
using System.Runtime.InteropServices;

/// <summary>
/// FAD-24 API library definitions
/// </summary>
public class FAD24
{
    //
    // Device status (Return codes)
    //
    public const int FAD24_OK = 0;
    public const int FAD24_INVALID_ID = 1;
    public const int FAD24_DEVICE_NOT_FOUND = 2;
    public const int FAD24_DEVICE_NOT_OPENED = 3;
    public const int FAD24_OTHER_ERROR = 4;
    public const int FAD24_COMMUNICATION_ERROR = 5;
    public const int FAD24_INVALID_PARAMETER = 6;

    //
    // Sampling Rate
    //
    public const int FAD24_SAMPLING_RATE_50KSPS = 1;
    public const int FAD24_SAMPLING_RATE_25KSPS = 2;
    public const int FAD24_SAMPLING_RATE_10KSPS = 5;
    public const int FAD24_SAMPLING_RATE_5KSPS = 10;
    public const int FAD24_SAMPLING_RATE_2_5KSPS = 20;
    public const int FAD24_SAMPLING_RATE_1KSPS = 50;
    public const int FAD24_SAMPLING_RATE_500SPS = 100;
    public const int FAD24_SAMPLING_RATE_250SPS = 200;
    public const int FAD24_SAMPLING_RATE_100SPS = 500;
    public const int FAD24_SAMPLING_RATE_50SPS = 1000;
    public const int FAD24_SAMPLING_RATE_25SPS = 2000;
    public const int FAD24_SAMPLING_RATE_10SPS = 5000;
    public const int FAD24_SAMPLING_RATE_5SPS = 10000;
    public const int FAD24_SAMPLING_RATE_2_5SPS = 20000;
    public const int FAD24_SAMPLING_RATE_1SPS = 50000;

    //
    // Sampling Edge
    //
    public const byte FAD24_SAMPLING_EDGE_ON = 0x00;
    public const byte FAD24_SAMPLING_EDGE_OFF = 0x01;

    //
    // Trigger Type
    //
    public const byte FAD24_TRIGGER_TYPE_NONE = 0x00;
    public const byte FAD24_TRIGGER_TYPE_LEVEL_H = 0x01;
    public const byte FAD24_TRIGGER_TYPE_LEVEL_L = 0x02;
    public const byte FAD24_TRIGGER_TYPE_SLOPE_RISING = 0x03;
    public const byte FAD24_TRIGGER_TYPE_SLOPE_FALLING = 0x04;
    public const byte FAD24_TRIGGER_TYPE_EDGE_ON = 0x05;
    public const byte FAD24_TRIGGER_TYPE_EDGE_OFF = 0x06;


    //
    // Device Functions
    //
    [DllImport("FAD24.dll")]
    public static extern int FAD24_GetNumberOfDevices (out int Number);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_GetSerialNumber (int Index, out int SerialNumber);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_Open (out byte ID);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_OpenBySerialNumber (int SerialNumber, out byte ID);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_Close(byte ID);

    //
    // A/D Functions
    //
    [DllImport("FAD24.dll")]
    public static extern int FAD24_Acquisition (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object Value, int SamplingRate, int SamplingCount, byte TriggerType, double TriggerThreshold, int TriggerWaitCount, out int AcquisitionCount);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_AcquisitionExt (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object Value, byte SamplingEdge, int SamplingCount, int SamplingEdgeWaitCount, byte TriggerType, double TriggerThreshold, int TriggerWaitCount, out int AcquisitionCount);
    [DllImport("FAD24.dll")]
    public static extern int FAD24_AcquisitionSingle (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object Value);
}
