/*++

Copyright (c) 2015-2016 ELMOS Co., Ltd.

Module Name:
	FAD24.h
Abstract:
	FAD24 API library definitions
Revision History:
	15/04/20	Created.
	16/08/05	Updated.

--*/

#ifndef FAD24_H
#define FAD24_H

#ifdef FAD24_EXPORTS_
#define FAD24_API __declspec(dllexport)
#else
#define FAD24_API __declspec(dllimport)
#endif

//
// Device status (Return Value)
//
enum {
    FAD24_OK,
    FAD24_INVALID_ID,
    FAD24_DEVICE_NOT_FOUND,
    FAD24_DEVICE_NOT_OPENED,
	FAD24_OTHER_ERROR,
	FAD24_COMMUNICATION_ERROR,
	FAD24_INVALID_PARAMETER
};

//
// Constants
//
#define	FAD24_SAMPLING_RATE_50KSPS	1
#define	FAD24_SAMPLING_RATE_25KSPS	2
#define	FAD24_SAMPLING_RATE_10KSPS	5
#define	FAD24_SAMPLING_RATE_5KSPS	10
#define	FAD24_SAMPLING_RATE_2_5KSPS	20
#define	FAD24_SAMPLING_RATE_1KSPS	50
#define	FAD24_SAMPLING_RATE_500SPS	100
#define	FAD24_SAMPLING_RATE_250SPS	200
#define	FAD24_SAMPLING_RATE_100SPS	500
#define	FAD24_SAMPLING_RATE_50SPS	1000
#define	FAD24_SAMPLING_RATE_25SPS	2000
#define	FAD24_SAMPLING_RATE_10SPS	5000
#define	FAD24_SAMPLING_RATE_5SPS	10000
#define	FAD24_SAMPLING_RATE_2_5SPS	20000
#define	FAD24_SAMPLING_RATE_1SPS	50000

#define	FAD24_SAMPLING_EDGE_ON		0
#define	FAD24_SAMPLING_EDGE_OFF		1

#define	FAD24_TRIGGER_TYPE_NONE				0
#define	FAD24_TRIGGER_TYPE_LEVEL_H			1
#define	FAD24_TRIGGER_TYPE_LEVEL_L			2
#define	FAD24_TRIGGER_TYPE_SLOPE_RISING		3
#define	FAD24_TRIGGER_TYPE_SLOPE_FALLING	4
#define	FAD24_TRIGGER_TYPE_EDGE_ON			5
#define	FAD24_TRIGGER_TYPE_EDGE_OFF			6

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
FAD24_API int WINAPI FAD24_GetNumberOfDevices (int *Number);
FAD24_API int WINAPI FAD24_GetSerialNumber (int Index, int *SerialNumber);
FAD24_API int WINAPI FAD24_Open (BYTE *ID);
FAD24_API int WINAPI FAD24_OpenBySerialNumber (int SerialNumber, BYTE *ID);
FAD24_API int WINAPI FAD24_Close (BYTE ID);
FAD24_API int WINAPI FAD24_Acquisition (BYTE ID, double *Value, int SamplingRate, int SamplingCount, BYTE TriggerType, double TriggerThreshold, int TriggerWaitCount, int *AcquisitionCount);
FAD24_API int WINAPI FAD24_AcquisitionExt (BYTE ID, double *Value, BYTE SamplingEdge, int SamplingCount, int SamplingEdgeWaitCount, BYTE TriggerType, double TriggerThreshold, int TriggerWaitCount, int *AcquisitionCount);
FAD24_API int WINAPI FAD24_AcquisitionSingle (BYTE ID, double *Value);

#ifdef __cplusplus
}
#endif

#endif  /* FAD24_H */
